import { useEffect, useState } from 'react';
import GridLayout from 'react-grid-layout';
import LoginScreen from '../components/login/loginScreen';
import Panel from '../components/panels/panel';
import { RawJSONVis } from '@graphpolaris/shared/lib/vis/rawjsonvis/rawjsonvis';
import SemanticSubstrates from '@graphpolaris/shared/lib/vis/semanticsubstrates/semanticsubstrates';
import { Schema } from '@graphpolaris/shared/lib/schema/panel';
import {
  GetAllDatabases,
  GetUserInfo,
} from '@graphpolaris/shared/lib/data-access/api';
import { QueryBuilder } from '@graphpolaris/shared/lib/querybuilder';
import {
  assignNewGraphQueryResult,
  useAppDispatch,
} from '@graphpolaris/shared/lib/data-access/store';
import {
  AuthorizationHandler,
  useAuthorization,
} from '@graphpolaris/shared/lib/data-access/authorization';
import { Navbar } from '../components/navbar/navbar';

export function App() {
  const dispatch = useAppDispatch();
  const authorization = useAuthorization();

  useEffect(() => {
    if (authorization.userAuthorized) {
      GetAllDatabases().then((d) => {
        console.log(d);
      });
    }
  }, [authorization.userAuthorized]);

  return (
    <>
      {!authorization.userAuthorized && <LoginScreen />}
      <Navbar />
      <GridLayout
        className="layout"
        cols={10}
        rowHeight={30}
        width={window.innerWidth}
      >
        <div
          key="schema-panel"
          data-grid={{ x: 0, y: 0, w: 3, h: 30, maxW: 5, isDraggable: false }}
        >
          <Panel content="Schema Panel" color="red">
            <Schema />
          </Panel>
        </div>
        <div
          key="query-panel"
          data-grid={{ x: 3, y: 20, w: 5, h: 10, maxH: 20, isDraggable: false }}
        >
          <Panel content="Query Panel" color="blue">
            <QueryBuilder />
          </Panel>
        </div>
        <div
          key="visualisation-panel"
          data-grid={{ x: 3, y: 0, w: 7, h: 20, isDraggable: false }}
        >
          <Panel content="Visualisation Panel" color="green">
            <div>
              <button
                onClick={() =>
                  dispatch(
                    assignNewGraphQueryResult({
                      nodes: [
                        {
                          id: 'agent/007',
                          attributes: { name: 'Daniel Craig' },
                        },
                      ],
                      links: [],
                    })
                  )
                }
              >
                Load in mock result
              </button>
              <button
                onClick={() =>
                  dispatch(assignNewGraphQueryResult({ nodes: [], links: [] }))
                }
              >
                Remove mock result
              </button>
            </div>
            {/* <RawJSONVis /> */}
            {/* <SemanticSubstrates /> */}
            <div />
          </Panel>
        </div>
        <div
          key="history-panel"
          data-grid={{ x: 8, y: 20, w: 2, h: 10, isDraggable: false }}
        >
          <Panel content="History Channel" color="purple"></Panel>
        </div>
      </GridLayout>
    </>
  );
}

export default App;
